export class Main extends Indicator {

    constructor() {
        super();

        this.setProperty(Property.SeparateWindow, true);

        this.setProperty(Property.Minimum, 0);
        this.setProperty(Property.Maximum, 1);

        this.addInput("TF", InputType.TimeFrame, 0);
        this.addInput("ADXPeriod", InputType.int, 14);
        this.addInput("PRICE", InputType.AppliedPrice, AppliedPrice.Close);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            ExtMapBuffer1 : this.addBuffer(),
            ExtMapBuffer2 : this.addBuffer(),
            ExtMapBuffer3 : this.addBuffer(),
            ExtMapBuffer4 : this.addBuffer(),
        };
    }

    onInit() {
        let shortName,
            {TF, TimeFrameStr} = this.getInputs();

        switch (TF) {
            case 1 :
                TimeFrameStr = "Period_M1";
                break;
            case 5 :
                TimeFrameStr = "Period_M5";
                break;
            case 15 :
                TimeFrameStr = "Period_M15";
                break;
            case 30 :
                TimeFrameStr = "Period_M30";
                break;
            case 60 :
                TimeFrameStr = "Period_H1";
                break;
            case 240 :
                TimeFrameStr = "Period_H4";
                break;
            case 1440 :
                TimeFrameStr = "Period_D1";
                break;
            case 10080 :
                TimeFrameStr = "Period_W1";
                break;
            case 43200 :
                TimeFrameStr = "Period_MN1";
                break;
            default :
                TimeFrameStr = "Current Timeframe";
                TF = 0;
        }

        shortName = "FILTER ADX(AM) (" + TimeFrameStr + ")";

        this.buffers.ExtMapBuffer1
            .setShape(Shape.Histogram)
            .setColor(Color.Red)
            .setShortName(shortName);

        this.buffers.ExtMapBuffer2
            .setShape(Shape.Histogram)
            .setColor(Color.Green)
            .setShortName(shortName);

        this.buffers.ExtMapBuffer3
            .setShape(Shape.Histogram)
            .setColor(Color.Red)
            .setShortName(shortName);

        this.buffers.ExtMapBuffer4
            .setShape(Shape.Histogram)
            .setColor(Color.Green)
            .setShortName(shortName);
    }

    async onUpdate() {
        const
            {ExtMapBuffer1, ExtMapBuffer2, ExtMapBuffer3, ExtMapBuffer4} = this.buffers,
            {TF, ADXPeriod, PRICE, PriceType} = this.getInputs(),
            barSize = await Bar.size();

        let ADX1, pDI1, mDI1, ADX2, pDI2, mDI2, limit, i, listADX0, listADX1, listADX2, list,
            countedBars = Bar.counted();

        if (countedBars < 0) return (-1);
        limit = barSize - countedBars;

        list = await Indicators.ADX(null, TF, ADXPeriod, PRICE, PriceType);
        listADX0 = list[0];
        listADX1 = list[1];
        listADX2 = list[2];

        for (i = limit-1; i >= 0; i--) {
            ExtMapBuffer1.set(i, 0);
            ExtMapBuffer2.set(i, 0);
            ExtMapBuffer3.set(i, 0);
            ExtMapBuffer4.set(i,  0);
            ADX1 = listADX0[i] || 0;
            pDI1 = listADX1[i] || 0;
            mDI1 = listADX2[i] || 0;
            ADX2 = listADX0[i + 1] || 0;
            pDI2 = listADX1[i + 1] || 0;
            mDI2 = listADX2[i + 1] || 0;

            if (pDI1 < mDI1 && ADX1 > ADX2) {
                ExtMapBuffer1.set(i, 1);
            }
            if (pDI1 > mDI1 && ADX1 > ADX2) {
                ExtMapBuffer2.set(i, 1);
            }
            if (pDI1 < mDI1 && ADX1 < ADX2) {
                ExtMapBuffer3.set(i, 1);
            }
            if (pDI1 > mDI1 && ADX1 < ADX2) {
                ExtMapBuffer4.set(i, 1);
            }
        }


    }
}
